<?php
/**
 * Template Tags
 *
 * Functions that are called directly from template parts or within actions.
 *
 * @package Schematic
 */

if ( ! function_exists( 'csco_header_nav_menu' ) ) {
	class CSCO_NAV_Walker extends Walker_Nav_Menu {
		/**
		 * Starts the list before the elements are added.
		 *
		 * @since 3.0.0
		 *
		 * @see Walker::start_lvl()
		 *
		 * @param string   $output Used to append additional content (passed by reference).
		 * @param int      $depth  Depth of menu item. Used for padding.
		 * @param stdClass $args   An object of wp_nav_menu() arguments.
		 */
		public function start_lvl( &$output, $depth = 0, $args = null ) {
			if ( isset( $args->item_spacing ) && 'discard' === $args->item_spacing ) {
				$t = '';
				$n = '';
			} else {
				$t = "\t";
				$n = "\n";
			}
			$indent = str_repeat( $t, $depth );

			$classes = array( 'sub-menu' );

			$scheme = csco_color_scheme(
				get_theme_mod( 'color_header_elements_background', '#f8f8f8' ),
				get_theme_mod( 'color_header_elements_background_dark', '#292929' )
			);

			/**
			 * Filters the CSS class(es) applied to a menu list element.
			 *
			 * @since 4.8.0
			 *
			 * @param string[] $classes Array of the CSS classes that are applied to the menu `<ul>` element.
			 * @param stdClass $args    An object of `wp_nav_menu()` arguments.
			 * @param int      $depth   Depth of menu item. Used for padding.
			 */
			$class_names = join( ' ', apply_filters( 'nav_menu_submenu_css_class', $classes, $args, $depth ) );
			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			$output .= "{$n}{$indent}<ul$class_names {$scheme}>{$n}";
		}
	}

	/**
	 * Header Nav Menu
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_nav_menu( $settings = array() ) {
		if ( ! get_theme_mod( 'header_navigation_menu', true ) ) {
			return;
		}

		if ( has_nav_menu( 'primary' ) ) {
			wp_nav_menu(
				array(
					'menu_class'      => 'cs-header__nav-inner',
					'theme_location'  => 'primary',
					'container'       => 'nav',
					'container_class' => 'cs-header__nav',
					'walker'          => new CSCO_NAV_Walker(),
				)
			);
		}
	}
}

if ( ! function_exists( 'csco_fullscreen_nav_menu' ) ) {
	/**
	 * Fullscreen Nav Menu
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_fullscreen_nav_menu( $settings = array() ) {
		if ( ! get_theme_mod( 'header_fullscreen_menu', true ) ) {
			return;
		}

		$items_wrap_after = '<div class="cs-fullscreen-menu__nav-col cs-fullscreen-menu__nav-col-first"></div>
					<div class="cs-fullscreen-menu__nav-col cs-fullscreen-menu__nav-col-last"></div>';

		if ( has_nav_menu( 'fullscreen' ) ) {
			wp_nav_menu(
				array(
					'theme_location'  => 'fullscreen',
					'container_class' => 'cs-fullscreen-menu__nav',
					'menu_class'      => 'cs-fullscreen-menu__nav-inner',
					'items_wrap'      => '<ul class="%2$s">%3$s</ul>' . wp_kses( $items_wrap_after, 'csco' ),
					'fallback_cb'     => '__return_empty_string',
				)
			);
		}
	}
}

if ( ! function_exists( 'csco_header_logo' ) ) {
	/**
	 * Header Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_logo( $settings = array() ) {

		$logo_default_name = 'logo';
		$logo_dark_name    = 'logo_dark';
		$logo_class        = null;

		$settings = array_merge(
			array(
				'variant' => null,
			),
			$settings
		);

		// For hide logo.
		if ( 'hide' === $settings['variant'] ) {
			$logo_class = 'cs-logo-hide';
		}

		// Get default logo.
		$logo_url = get_theme_mod( $logo_default_name );

		$logo_id = attachment_url_to_postid( $logo_url );

		// Set mode of logo.
		$logo_mode = 'cs-logo-once';

		// Check display mode.
		if ( $logo_id ) {
			$logo_mode = 'cs-logo-default';
		}
		?>
		<div class="cs-logo">
			<a class="cs-header__logo <?php echo esc_attr( $logo_mode ); ?> <?php echo esc_attr( $logo_class ); ?>" href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>

			<?php
			if ( 'cs-logo-default' === $logo_mode ) {

				$logo_dark_url = get_theme_mod( $logo_dark_name ) ? get_theme_mod( $logo_dark_name ) : $logo_url;

				$logo_dark_id = attachment_url_to_postid( $logo_dark_url );

				if ( $logo_dark_id ) {
					?>
						<a class="cs-header__logo cs-logo-dark <?php echo esc_attr( $logo_class ); ?>" href="<?php echo esc_url( home_url( '/' ) ); ?>">
							<?php csco_get_retina_image( $logo_dark_id, array( 'alt' => get_bloginfo( 'name' ) ) ); ?>
						</a>
					<?php
				}
			}
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_header_tagline' ) ) {
	/**
	 * Header Tagline
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_tagline( $settings = array() ) {
		?>
		<div class="cs-header__tag-line"><?php bloginfo( 'description' ); ?></div>
		<?php
	}
}

if ( ! function_exists( 'csco_header_offcanvas_toggle' ) ) {
	/**
	 * Header Offcanvas Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_offcanvas_toggle( $settings = array() ) {

		if ( csco_offcanvas_exists() ) {

			$class = null;

			if ( ! get_theme_mod( 'header_offcanvas', true ) ) {
				$class = ' cs-d-lg-none';
			}

			if ( ! is_active_sidebar( 'sidebar-offcanvas' ) ) {
				$class = ' cs-d-lg-none';
			}
			?>
				<span class="cs-header__offcanvas-toggle <?php echo esc_attr( $class ); ?>" role="button">
					<i class="cs-icon cs-icon-more-vertical"></i>
				</span>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_header_search_toggle' ) ) {
	/**
	 * Header Search Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_search_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'header_search_display', true ) ) {
			return;
		}
		?>
		<span class="cs-header__search-toggle" role="button">
			<span class="cs-header__search-toggle-label"><?php esc_html_e( 'Search', 'schematic' ); ?></span>
			<i class="cs-icon cs-icon-search"></i>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_search_form' ) ) {
	/**
	 * Header Search Form
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_search_form( $settings = array() ) {
		if ( ! get_theme_mod( 'header_search_form', true ) ) {
			return;
		}
		?>
		<form role="search" method="get" class="cs-search__nav-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
			<div class="cs-search__group">
				<button class="cs-search__submit">
					<i class="cs-icon cs-icon-search"></i>
				</button>

				<input required class="cs-search__input" data-swpparentel=".cs-header .cs-search-live-result-container" data-swplive="true" type="search" value="<?php the_search_query(); ?>" name="s" placeholder="<?php echo esc_attr( esc_html__( 'Enter keyword', 'schematic' ) ); ?>">

				<button class="cs-search__close">
					<i class="cs-icon cs-icon-x"></i>
				</button>
			</div>
		</form>
		<?php
	}
}

if ( ! function_exists( 'csco_header_fullscreen_menu_toggle' ) ) {
	/**
	 * Header Fullscreen Menu Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_fullscreen_menu_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'header_fullscreen_menu', true ) ) {
			return;
		}

		$is_content = __return_false();

		if ( has_nav_menu( 'fullscreen' ) ) {
			$is_content = __return_true();
		}

		if ( is_active_sidebar( 'sidebar-fullscreen' ) ) {
			$is_content = __return_true();
		}

		if ( get_theme_mod( 'header_fullscreen_posts', false ) ) {

			ob_start();

			csco_header_fullscreen_posts();

			$stack_fullscreen_posts = ob_get_clean();

			if ( $stack_fullscreen_posts ) {
				$is_content = __return_true();
			}
		}

		if ( ! $is_content ) {
			return;
		}
		?>
		<span class="cs-header__fullscreen-menu-toggle" role="button">
			<span class="cs-header__fullscreen-menu-toggle-label"><?php esc_html_e( 'Menu', 'schematic' ); ?></span>
			<span class="cs-header__fullscreen-menu-toggle-inner">
				<span class="toggle-line"></span>
			</span>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_scheme_toggle' ) ) {
	/**
	 * Header Scheme Toggle
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_scheme_toggle( $settings = array() ) {
		if ( ! get_theme_mod( 'color_scheme_toggle', true ) ) {
			return;
		}
		?>
			<span role="button" class="cs-header__scheme-toggle cs-site-scheme-toggle">
				<span class="cs-header__scheme-toggle-label cs-header__scheme-toggle-label-dark"><?php esc_html_e( 'dark mode', 'schematic' ); ?></span>
				<span class="cs-header__scheme-toggle-label cs-header__scheme-toggle-label-light"><?php esc_html_e( 'light mode', 'schematic' ); ?></span>
				<span class="cs-header__scheme-toggle-icons">
					<i class="cs-header__scheme-toggle-icon cs-icon cs-icon-light-mode"></i>
					<i class="cs-header__scheme-toggle-icon cs-icon cs-icon-moon"></i>
				</span>
			</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_scheme_toggle_mobile' ) ) {
	/**
	 * Header Scheme Toggle Mobile
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_scheme_toggle_mobile( $settings = array() ) {
		if ( ! get_theme_mod( 'color_scheme_toggle', true ) ) {
			return;
		}
		?>
		<span role="button" class="cs-header__scheme-toggle cs-header__scheme-toggle-mobile cs-site-scheme-toggle">
			<span class="cs-header__scheme-toggle-icons">
				<i class="cs-header__scheme-toggle-icon cs-icon cs-icon-light-mode"></i>
				<i class="cs-header__scheme-toggle-icon cs-icon cs-icon-moon"></i>
			</span>
		</span>
		<?php
	}
}

if ( ! function_exists( 'csco_header_fullscreen_widgets' ) ) {
	/**
	 * Header Fullscreen Widgets
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_fullscreen_widgets( $settings = array() ) {

		if ( ! is_active_sidebar( 'sidebar-fullscreen' ) ) {
			return;
		}

		?>
		<div class="cs-fullscreen-menu__widgets cs-widget-area">
			<?php dynamic_sidebar( 'sidebar-fullscreen' ); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_header_link' ) ) {
	/**
	 * Header Link
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_link( $settings = array() ) {
		$url   = get_theme_mod( 'header_link_url' );
		$label = get_theme_mod( 'header_link_label' );

		if ( $label && $url ) {
			?>
			<a href="<?php echo esc_url( $url ); ?>" class="cs-header__custom-link" target="_blank">
				<?php echo wp_kses( $label, 'csco' ); ?>
			</a>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_header_social_links' ) ) {
	/**
	 * Header Social Links
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_header_social_links( $settings = array() ) {

		if ( ! get_theme_mod( 'header_social_links', false ) ) {
			return;
		}

		if ( ! csco_powerkit_module_enabled( 'social_links' ) ) {
			return;
		}

		$scheme  = get_theme_mod( 'header_social_links_scheme', 'default' );
		$maximum = get_theme_mod( 'header_social_links_maximum', 3 );
		$counts  = get_theme_mod( 'header_social_links_counts', true );
		?>
		<div class="cs-navbar-social-links">
			<?php powerkit_social_links( false, false, $counts, 'nav', $scheme, 'mixed', $maximum ); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_footer_logo' ) ) {
	/**
	 * Footer Logo
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_logo( $settings = array() ) {
		$logo_url = get_theme_mod( 'footer_logo' );

		$logo_id = attachment_url_to_postid( $logo_url );

		$logo_mode = 'cs-logo-once';

		if ( $logo_id ) {
			$logo_mode = 'cs-logo-default';
		}
		?>
		<div class="cs-logo">
			<a class="cs-footer__logo <?php echo esc_attr( $logo_mode ); ?>" href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<?php
				if ( $logo_id ) {
					csco_get_retina_image( $logo_id, array( 'alt' => get_bloginfo( 'name' ) ) );
				} else {
					bloginfo( 'name' );
				}
				?>
			</a>

			<?php
			if ( 'cs-logo-default' === $logo_mode ) {

				$logo_dark_url = get_theme_mod( 'footer_logo_dark' ) ? get_theme_mod( 'footer_logo_dark' ) : $logo_url;

				$logo_dark_id = attachment_url_to_postid( $logo_dark_url );

				if ( $logo_dark_id ) {
					?>
						<a class="cs-footer__logo cs-logo-dark" href="<?php echo esc_url( home_url( '/' ) ); ?>">
							<?php csco_get_retina_image( $logo_dark_id, array( 'alt' => get_bloginfo( 'name' ) ) ); ?>
						</a>
					<?php
				}
			}
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_footer_tagline' ) ) {
	/**
	 * Footer Tagline
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_tagline( $settings = array() ) {
		?>
		<div class="cs-footer__tag-line"><?php bloginfo( 'description' ); ?></div>
		<?php
	}
}

if ( ! function_exists( 'csco_footer_info' ) ) {
	/**
	 * Footer Info
	 */
	function csco_footer_info() {
		/* translators: %s: Author name. */
		$footer_text = get_theme_mod( 'footer_text' );
		if ( $footer_text ) {
			?>
			<div class="cs-footer__info">
				<?php echo do_shortcode( $footer_text ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_footer_menu' ) ) {
	/**
	 * Footer Menu
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_menu( $settings = array() ) {

		$settings = array_merge( array(
			'menu_class' => null,
			'lacation'   => null,
			'compact'    => null,
		), $settings );

		if ( has_nav_menu( $settings['location'] ) ) {
			$items_wrap_before = '';

			$menu_name = wp_get_nav_menu_name( $settings['location'] );

			if ( $menu_name && null === $settings['compact'] ) {
				$items_wrap_before = '<span class="cs-footer__nav-label">' . esc_html( $menu_name ) . '</span>';
			}

			wp_nav_menu(
				array(
					'theme_location'  => $settings['location'],
					'container'       => 'div',
					'container_class' => 'cs-footer__nav-item',
					'menu_class'      => sprintf( 'cs-footer__nav-inner %s', $settings['menu_class'] ),
					'depth'           => 1,
					'fallback_cb'     => '__return_empty_string',
					'items_wrap'      => wp_kses( $items_wrap_before, 'csco' ) . '<ul class="%2$s">%3$s</ul>',
				)
			);
		}
	}
}

if ( ! function_exists( 'csco_footer_social_links' ) ) {
	/**
	 * Footer Social Links
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_social_links( $settings = array() ) {

		$settings = array_merge( array(
			'compact' => null,
		), $settings );

		if ( ! get_theme_mod( 'footer_social_links', false ) ) {
			return;
		}

		if ( ! csco_powerkit_module_enabled( 'social_links' ) ) {
			return;
		}

		$scheme  = get_theme_mod( 'footer_social_links_scheme', 'default' );
		$maximum = get_theme_mod( 'footer_social_links_maximum', 3 );
		$counts  = get_theme_mod( 'footer_social_links_counts', true );
		$label   = get_theme_mod( 'footer_social_links_label', esc_html__( 'Networking', 'schematic' ) );
		$titles  = true;
		if ( 'three' === get_theme_mod( 'footer_layout' ) ) {
			$titles = false;
		}

		if ( true === $settings['compact'] ) {
			?>
			<div class="cs-footer-social-links">
				<?php powerkit_social_links( false, $titles, $counts, 'nav', $scheme, 'mixed', $maximum ); ?>
			</div>
			<?php
		} else {
			?>
			<div class="cs-footer__nav-item">
				<?php if ( $label ) { ?>
					<span class="cs-footer__nav-label"><?php echo esc_html( $label ); ?></span>
				<?php } ?>
				<div class="cs-footer-social-links">
					<?php powerkit_social_links( false, $titles, $counts, 'nav', $scheme, 'mixed', $maximum ); ?>
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_footer_subscription_form' ) ) {
	/**
	 * Footer Subscription Form
	 */
	function csco_footer_subscription_form() {

		if ( ! get_theme_mod( 'footer_subscribe', false ) ) {
			return;
		}

		$subscribe_title = get_theme_mod( 'footer_subscribe_title', esc_html__( 'Subscribe to our newsletter and get posts every week', 'schematic' ) );
		$subscribe_text  = get_theme_mod( 'footer_subscribe_text', esc_html__( 'Get notified of the best deals on our WordPress themes.', 'schematic' ) );
		$subscribe_name  = get_theme_mod( 'footer_subscribe_name', true );

		?>

		<div class="cs-site-subscribe">
			<div class="cs-container">
				<div class="cs-site-subscribe__item">
					<div class="cs-site-subscribe__form">
						<?php if ( $subscribe_title || $subscribe_text ) { ?>
							<div class="cs-site-subscribe__info">
								<?php if ( $subscribe_title ) { ?>
									<h5 class="cs-site-subscribe__title">
										<?php echo wp_kses( $subscribe_title, 'csco' ); ?>
									</h5>
								<?php } ?>

								<?php if ( $subscribe_text ) { ?>
									<div class="cs-site-subscribe__info-text"><?php echo wp_kses( $subscribe_text, 'csco' ); ?></div>
								<?php } ?>
							</div>
						<?php } ?>

						<?php echo do_shortcode( sprintf( '[powerkit_subscription_form display_name="%1$s" %2$s="" text=""]', $subscribe_name, 'title' ) ); ?>
					</div>
				</div>
			</div>
		</div>

		<?php
	}
}

if ( ! function_exists( 'csco_footer_instagram' ) ) {
	/**
	 * Footer Instagraam
	 *
	 * @param array $settings The advanced settings.
	 */
	function csco_footer_instagram( $settings = array() ) {
		$username = get_theme_mod( 'footer_instagram_username' );

		$type = get_theme_mod( 'footer_instagram_type', 'type-2' );

		if ( 'default' !== $type ) {
			add_filter( 'powerkit_instagram_templates', 'csco_footer_instagram_default', 20 );
		}

		if ( $username && csco_powerkit_module_enabled( 'instagram_integration' ) ) {

			$classes = 'cs-footer-instagram';
			if ( 'default' !== $type ) {
				$classes .= ' cs-layout__instagram cs-layout__instagram-' . esc_attr( $type );
			}
			?>
			<div class="<?php echo esc_attr( $classes ); ?>">
				<div class="cs-container">
				<?php
					powerkit_instagram_get_recent(
						array(
							'user_id' => $username,
							'header'  => get_theme_mod( 'footer_instagram_header', true ),
							'number'  => get_theme_mod( 'footer_instagram_number', 4 ),
							'columns' => get_theme_mod( 'footer_instagram_columns_desktop', 4 ),
							'size'    => get_theme_mod( 'footer_instagram_size', 'small' ),
							'button'  => get_theme_mod( 'footer_instagram_button', true ),
							'target'  => '_blank',
						)
					);
				?>
				</div>
			</div>
			<?php
		}

		if ( 'default' !== $type ) {
			$function = sprintf( 'remove_%s', 'filter' );

			$function( 'powerkit_instagram_templates', 'csco_footer_instagram_default', 20 );
		}
	}
}

if ( ! function_exists( 'csco_block_post_parse_gallery' ) ) {
	/**
	 * Parse post gallery
	 *
	 * @param array $block The block.
	 */
	function csco_block_post_parse_gallery( $block = array() ) {
		$stack = __return_empty_array();

		if ( 'core/gallery' === $block['blockName'] && isset( $block['innerBlocks'] ) ) {
			foreach ( $block['innerBlocks'] as $inner_item ) {
				if ( 'core/image' === $inner_item['blockName'] && isset( $inner_item['attrs']['id'] ) ) {
					$stack[] = $inner_item['attrs']['id'];
				}
			}
		}
		if ( 'sight/portfolio' === $block['blockName'] && isset( $block['attrs']['source'] ) && isset( $block['attrs']['custom_images'] ) ) {
			if ( 'custom' === $block['attrs']['source'] && $block['attrs']['custom_images'] ) {
				$custom_images = (array) $block['attrs']['custom_images'];

				if ( isset( $block['attrs']['number_items'] ) && $block['attrs']['number_items'] ) {
					$custom_images = array_slice( $custom_images, 0, $block['attrs']['number_items'] );
				}

				$stack = array_merge( $stack, $custom_images );
			}
		}
		if ( isset( $block['innerBlocks'] ) && $block['innerBlocks'] ) {
			foreach ( $block['innerBlocks'] as $inner_item ) {
				$stack = array_merge( $stack, csco_block_post_parse_gallery( $inner_item ) );
			}
		}

		return $stack;
	}
}

if ( ! function_exists( 'csco_the_post_format_icon' ) ) {
	/**
	 * Post Format Icon
	 *
	 * @param string $content After content.
	 */
	function csco_the_post_format_icon( $content = '' ) {
		$post_format = get_post_format();

		if ( $post_format ) {
			if ( 'gallery' === $post_format ) {
				$post = get_post();

				$blocks = parse_blocks( $post->post_content );

				$attachments = __return_empty_array();

				foreach ( $blocks as $block ) {
					$attachments = array_merge( $attachments, csco_block_post_parse_gallery( $block ) );
				}

				$content = $attachments ? sprintf( '<span>%s</span>', count( $attachments ) ) : '';
			}
			?>
			<span class="cs-entry-format">
				<a class="cs-format-icon cs-format-<?php echo esc_attr( $post_format ); ?>" href="<?php the_permalink(); ?>">
					<?php echo wp_kses( $content, 'csco' ); ?>
				</a>
			</span>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_post_subtitle' ) ) {
	/**
	 * Post Subtitle
	 */
	function csco_post_subtitle() {
		if ( ! is_single() ) {
			return;
		}

		if ( get_theme_mod( 'post_subtitle', true ) ) {
			$subtitle = apply_filters( 'plugins/wp_subtitle/get_subtitle', '', array(
				'before'  => '',
				'after'   => '',
				'post_id' => get_the_ID(),
			) );

			if ( $subtitle ) {
				?>
				<div class="cs-entry__subtitle">
					<?php echo wp_kses( $subtitle, 'csco' ); ?>
				</div>
				<?php
			} elseif ( has_excerpt() ) {
				?>
				<div class="cs-entry__subtitle">
					<?php the_excerpt(); ?>
				</div>
				<?php
			}
		}
	}
}

if ( ! function_exists( 'csco_post_author' ) ) {
	/**
	 * Post Author Details
	 *
	 * @param int $id Author ID.
	 */
	function csco_post_author( $id = null ) {
		if ( ! $id ) {
			$id = get_the_author_meta( 'ID' );
		}
		$count_user_posts = count_user_posts( $id );
		?>
		<div class="cs-entry__author-inner">
			<div class="cs-entry__author-photo-wrapper">
				<a href="<?php echo esc_url( get_author_posts_url( $id ) ); ?>" class="cs-entry__author-photo">
					<?php echo get_avatar( $id, '56' ); ?>
				</a>
				<div class="cs-entry__author-name-wrapper">
					<?php
					$job_title = get_the_author_meta( 'csco_job_title', $id );
					if ( $job_title ) {
						?>
						<span class="cs-entry__author-position">
							<?php echo esc_html( $job_title ); ?>
						</span>
						<?php
					}
					?>

					<a href="<?php echo esc_url( get_author_posts_url( $id ) ); ?>" class="cs-entry__author-name">
						<?php the_author_meta( 'display_name', $id ); ?>
					</a>

					<span class="cs-entry__author-posts"><?php echo sprintf( esc_html( _n( '%s post', '%s posts', $count_user_posts, 'schematic' ) ), $count_user_posts ); ?></span>
				</div>
			</div>

			<div class="cs-entry__author-info">
				<?php if ( get_the_author_meta( 'description', $id ) ) { ?>
					<div class="cs-entry__author-description"><?php the_author_meta( 'description', $id ); ?></div>
				<?php } ?>

				<?php if ( csco_powerkit_module_enabled( 'social_links' ) ) { ?>
					<div class="cs-entry__author-social">
						<?php csco_powerkit_author_social_links( $id, 'custom', true ); ?>
					</div>
				<?php } ?>
			</div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_archive_post_description' ) ) {
	/**
	 * Post Description in Archive Pages
	 */
	function csco_archive_post_description() {
		$description = get_the_archive_description();
		if ( $description ) {
			?>
			<div class="cs-page__archive-description">
				<?php echo do_shortcode( $description ); ?>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_archive_post_count' ) ) {
	/**
	 * Post Count in Archive Pages
	 */
	function csco_archive_post_count() {
		global $wp_query;
		$found_posts = $wp_query->found_posts;
		?>
		<div class="cs-page__archive-count">
			<?php
			/* translators: 1: Singular, 2: Plural. */
			echo esc_html( apply_filters( 'csco_article_full_count', sprintf( _n( '%s post', '%s posts', $found_posts, 'schematic' ), $found_posts ), $found_posts ) );
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_live_search_post_count' ) ) {
	/**
	 * Post Count in Live Search
	 */
	function csco_live_search_post_count() {
		global $wp_query;
		$found_posts = $wp_query->found_posts;
		?>
		<div class="cs-search-live-count">
			<?php
			/* translators: 1: Singular, 2: Plural. */
			echo esc_html( sprintf( _n( '%s Result', '%s Results', $found_posts, 'schematic' ), $found_posts ) );
			?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'csco_subcategories' ) ) {
	/**
	 * Subcategories
	 */
	function csco_subcategories() {

		if ( ! get_theme_mod( 'category_subcategories', true ) ) {
			return;
		}

		if ( ! is_category() ) {
			return;
		}

		$args = apply_filters(
			'csco_subcategories_args',
			array(
				'parent' => get_query_var( 'cat' ),
			)
		);

		$categories = get_categories( $args );

		if ( $categories ) {
			?>
			<div class="cs-page__subcategories">
				<?php csco_section_heading( esc_html__( 'Subcategories', 'schematic' ) ); ?>

				<div class="cs-page__tags">
					<ul>
						<?php
						foreach ( $categories as $category ) {
							// Translators: category name.
							$title = sprintf( esc_html__( 'View all posts in %s', 'schematic' ), $category->name );
							$link  = get_category_link( $category->term_id )
							?>
								<li>
									<a href="<?php echo esc_url( $link ); ?>" title="<?php echo esc_attr( $title ); ?>">
										<?php echo esc_html( $category->name ); ?>
									</a>
								</li>
							<?php
						}
						?>
					</ul>
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_header_fullscreen_posts' ) ) {
	/**
	 * Header fullscreen posts
	 */
	function csco_header_fullscreen_posts() {

		if ( ! get_theme_mod( 'header_fullscreen_posts', false ) ) {
			return;
		}

		$options = array(
			'image_display'     => get_theme_mod( 'header_fullscreen_preview_image', true ),
			'excerpt'           => get_theme_mod( 'header_fullscreen_excerpt', false ),
			'image_orientation' => get_theme_mod( 'header_fullscreen_image_orientation', 'square' ),
			'image_size'        => get_theme_mod( 'header_fullscreen_image_size', 'thumbnail' ),
		);

		$query_args = array(
			'order'               => get_theme_mod( 'header_fullscreen_posts_order', 'DESC' ),
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => 4,
		);

		// Post orderby.
		$orderby = get_theme_mod( 'header_fullscreen_posts_orderby', 'date' );
		if ( 'post_views' === $orderby ) {
			if ( class_exists( 'Post_Views_Counter' ) ) {
				// Post Views.
				$query_args['orderby'] = 'post_views';
				// Don't hide posts without views.
				$query_args['views_query']['hide_empty'] = false;
				// Time Frame for Post Views.
				$time_frame = get_theme_mod( 'header_fullscreen_time_frame' );
				if ( $time_frame ) {
					$query_args['date_query'] = array(
						array(
							'column' => 'post_date_gmt',
							'after'  => $time_frame . ' ago',
						),
					);
				}
			} else {
				$query_args['orderby'] = 'date';
			}
		} else {
			$query_args['orderby'] = $orderby;
		}

		// Filter by posts.
		$filter_posts = get_theme_mod( 'header_fullscreen_filter_posts' );
		if ( $filter_posts ) {
			$query_args['post__in'] = array_map( 'trim', explode( ',', $filter_posts ) );
		}

		// Filter by categories.
		$filter_categories = get_theme_mod( 'header_fullscreen_filter_categories' );
		if ( $filter_categories ) {
			$filter_categories       = array_map( 'trim', explode( ',', $filter_categories ) );
			$query_args['tax_query'] = array(
				array(
					'taxonomy'         => 'category',
					'field'            => 'slug',
					'terms'            => $filter_categories,
					'include_children' => true,
				),
			);
		}

		// Filter by tags.
		$filter_tags = get_theme_mod( 'header_fullscreen_filter_tags' );
		if ( $filter_tags ) {
			$query_args['tag'] = array_map( 'trim', explode( ',', $filter_tags ) );
		}

		// WP Query.
		$items = new WP_Query( $query_args );

		if ( $items->have_posts() ) {
			$heading      = get_theme_mod( 'header_fullscreen_posts_heading', esc_html__( 'The Latest', 'schematic' ) );
			$heading_args = array(
				'link_label' => get_theme_mod( 'header_fullscreen_posts_label', esc_html__( 'View All', 'schematic' ) ),
				'link_url'   => get_theme_mod( 'header_fullscreen_posts_url' ),
			);
			?>
			<div class="cs-header__multi-column-posts-wrapper">
				<?php csco_section_heading( $heading, 'full', true, '', 'default', $heading_args ); ?>

				<div class="cs-header__multi-column-posts">
					<?php
					while ( $items->have_posts() ) {
						$items->the_post();
						?>
						<article <?php post_class(); ?>>
							<div class="cs-entry__outer">
								<?php if ( has_post_thumbnail() && true === $options['image_display'] ) { ?>
									<div class="cs-entry__inner cs-entry__thumbnail cs-entry__overlay cs-overlay-ratio cs-ratio-<?php echo esc_attr( $options['image_orientation'] ); ?>" data-scheme="inverse">
										<div class="cs-overlay-background cs-overlay-transparent">
											<?php the_post_thumbnail( $options['image_size'] ); ?>
										</div>

										<a href="<?php echo esc_url( get_permalink() ); ?>" class="cs-overlay-link"></a>
									</div>
								<?php } ?>
								<div class="cs-entry__inner cs-entry__content">
									<?php csco_get_post_meta( array( 'category', 'author', 'date', 'comments', 'reading_time', 'views', 'shares' ), false, true, 'header_fullscreen_posts_meta' ); ?>

									<?php the_title( '<h2 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' ); ?>

									<?php if ( csco_get_the_excerpt() && $options['excerpt'] ) { ?>
										<p class="cs-entry__excerpt"><?php echo esc_html( csco_get_post_excerpt() ); ?></p>
									<?php } ?>
								</div>
							</div>
						</article>

					<?php } ?>
				</div>
			</div>
			<?php
		}

		wp_reset_postdata();

	}
}

if ( ! function_exists( 'csco_header_search_posts' ) ) {
	/**
	 * Header search posts
	 */
	function csco_header_search_posts() {

		if ( ! get_theme_mod( 'header_search_posts', false ) ) {
			return;
		}

		$options = array(
			'image_display'     => get_theme_mod( 'header_search_preview_image', false ),
			'excerpt'           => get_theme_mod( 'header_search_excerpt', false ),
			'image_orientation' => get_theme_mod( 'header_search_image_orientation', 'landscape-16-9' ),
			'image_size'        => get_theme_mod( 'header_search_image_size', 'csco-thumbnail' ),
		);

		$query_args = array(
			'order'               => get_theme_mod( 'header_search_posts_order', 'DESC' ),
			'post_type'           => 'post',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => 4,
		);

		// Post orderby.
		$orderby = get_theme_mod( 'header_search_posts_orderby', 'date' );
		if ( 'post_views' === $orderby ) {
			if ( class_exists( 'Post_Views_Counter' ) ) {
				// Post Views.
				$query_args['orderby'] = 'post_views';
				// Don't hide posts without views.
				$query_args['views_query']['hide_empty'] = false;
				// Time Frame for Post Views.
				$time_frame = get_theme_mod( 'header_search_time_frame' );
				if ( $time_frame ) {
					$query_args['date_query'] = array(
						array(
							'column' => 'post_date_gmt',
							'after'  => $time_frame . ' ago',
						),
					);
				}
			} else {
				$query_args['orderby'] = 'date';
			}
		} else {
			$query_args['orderby'] = $orderby;
		}

		// Filter by posts.
		$filter_posts = get_theme_mod( 'header_search_filter_posts' );
		if ( $filter_posts ) {
			$query_args['post__in'] = array_map( 'trim', explode( ',', $filter_posts ) );
		}

		// Filter by categories.
		$filter_categories = get_theme_mod( 'header_search_filter_categories' );
		if ( $filter_categories ) {
			$filter_categories       = array_map( 'trim', explode( ',', $filter_categories ) );
			$query_args['tax_query'] = array(
				array(
					'taxonomy'         => 'category',
					'field'            => 'slug',
					'terms'            => $filter_categories,
					'include_children' => true,
				),
			);
		}

		// Filter by tags.
		$filter_tags = get_theme_mod( 'header_search_filter_tags' );
		if ( $filter_tags ) {
			$query_args['tag'] = array_map( 'trim', explode( ',', $filter_tags ) );
		}

		// WP Query.
		$items = new WP_Query( $query_args );

		if ( $items->have_posts() ) {
			$heading      = get_theme_mod( 'header_search_posts_heading', esc_html__( 'The Latest', 'schematic' ) );
			$heading_args = array(
				'link_label' => get_theme_mod( 'header_search_posts_label', esc_html__( 'View All', 'schematic' ) ),
				'link_url'   => get_theme_mod( 'header_search_posts_url' ),
			);
			?>
			<div class="cs-search__posts-wrapper">
				<?php csco_section_heading( $heading, 'full', true, '', 'default', $heading_args ); ?>

				<div class="cs-search__posts">
					<?php
					while ( $items->have_posts() ) {
						$items->the_post();
						?>
						<article <?php post_class(); ?>>
							<div class="cs-entry__outer">
								<?php if ( has_post_thumbnail() && true === $options['image_display'] ) { ?>
									<div class="cs-entry__inner cs-entry__thumbnail cs-entry__overlay cs-overlay-ratio cs-ratio-<?php echo esc_attr( $options['image_orientation'] ); ?>" data-scheme="inverse">
										<div class="cs-overlay-background cs-overlay-transparent">
											<?php the_post_thumbnail( $options['image_size'] ); ?>
										</div>

										<a href="<?php echo esc_url( get_permalink() ); ?>" class="cs-overlay-link"></a>
									</div>
								<?php } ?>
								<div class="cs-entry__inner cs-entry__content">
									<?php csco_get_post_meta( array( 'category', 'author', 'date', 'comments', 'reading_time', 'views', 'shares' ), false, true, 'header_search_posts_meta' ); ?>

									<?php the_title( '<h2 class="cs-entry__title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' ); ?>

									<?php if ( csco_get_the_excerpt() && $options['excerpt'] ) { ?>
										<p class="cs-entry__excerpt"><?php echo esc_html( csco_get_post_excerpt() ); ?></p>
									<?php } ?>
								</div>
							</div>
						</article>
					<?php } ?>
				</div>
			</div>
			<?php
		}

		wp_reset_postdata();
	}
}

if ( ! function_exists( 'csco_header_tags' ) ) {
	/**
	 * Header tags
	 *
	 * @param string $args Args.
	 */
	function csco_header_tags( $args = array() ) {

		if ( get_theme_mod( 'header_search_tags', true ) ) {
			$tags = get_terms( array(
				'taxonomy'   => 'post_tag',
				'number'     => get_theme_mod( 'header_search_tags_number', 10 ),
				'order'      => get_theme_mod( 'header_search_tags_order', 'DESC' ),
				'orderby'    => get_theme_mod( 'header_search_tags_orderby', 'date' ),
				'hide_empty' => false,
			) );

			if ( $tags && ! is_wp_error( $tags ) ) {
				?>
				<div class="cs-search__tags-wrapper">
					<h5 class="cs-search__tags-heading"><?php esc_html_e( 'Popular tags', 'schematic' ); ?></h5>
					<div class="cs-search__tags">
						<ul>
							<?php foreach ( $tags as $item ) { ?>
								<li>
									<a href="<?php echo esc_url( get_term_link( $item->term_id ) ); ?>" rel="tag">
										<?php echo esc_attr( $item->name ); ?>
									</a>
								</li>
							<?php } ?>
						</ul>
					</div>
				</div>
				<?php
			}
		}

	}
}

if ( ! function_exists( 'csco_entry_meta_author' ) ) {
	/**
	 * Entry Meta Author
	 *
	 * @param string $meta_location  The location meta.
	 */
	function csco_entry_meta_author( $meta_location = 'post_meta' ) {
		if ( 'post' !== get_post_type() ) {
			return;
		}

		if ( is_array( $meta_location ) ) {
			$post_author = in_array( 'author', $meta_location, true );
		} else {
			$post_author = csco_has_post_meta( 'author', $meta_location );
		}

		if ( $post_author ) {
			?>
			<div class="cs-entry__post-meta">
				<div class="cs-entry__details-data">

					<?php
					$authors_list = array();

					$authors = array( get_the_author_meta( 'ID' ) );

					if ( csco_coauthors_enabled() ) {
						$authors = csco_get_coauthors();
					}

					if ( $authors ) {
						foreach ( $authors as $author ) {

							$author_id   = isset( $author->ID ) ? $author->ID : $author;
							$author_name = isset( $author->display_name ) ? $author->display_name : get_the_author_meta( 'display_name', $author_id );
							$author_url  = get_author_posts_url( $author_id, isset( $author->user_nicename ) ? $author->user_nicename : '' );
							?>
							<div class="cs-entry__details-inner">
								<?php
								if ( get_avatar( $author_id ) ) {
									?>
									<div class="cs-author-avatar">
										<a href="<?php echo esc_url( $author_url ); ?>" rel="author"><?php echo get_avatar( $author_id, 64 ); ?></a>
									</div>
									<?php
								}
								?>

								<div class="cs-entry__details-meta">
									<div class="cs-entry__author-meta">
										<a href="<?php echo esc_url( $author_url ); ?>">
											<?php echo esc_html( $author_name ); ?>
										</a>
									</div>

									<?php
									$job_title = get_the_author_meta( 'csco_job_title', $author_id );
									if ( $job_title ) {
										?>
										<div class="cs-entry__author-job-title">
											<?php echo esc_html( $job_title ); ?>
										</div>
										<?php
									}
									?>
								</div>
							</div>
							<?php
						}
					}
					?>
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'csco_entry_post_meta' ) ) {
	/**
	 * Entry Post Meta
	 */
	function csco_entry_post_meta() {
		if ( ! is_single() ) {
			return;
		}

		get_template_part( 'template-parts/entry/entry-post-meta' );
	}
}

if ( ! function_exists( 'csco_entry_post_gallery' ) ) {
	/**
	 * Output post gallery
	 *
	 * @param array $options The options.
	 */
	function csco_entry_post_gallery( $options = array() ) {
		$images = array();

		// Add thumbnail id to array.
		if ( has_post_thumbnail() ) {
			$images[] = get_post_thumbnail_id();
		}

		// If is post format gallery.
		if ( 'gallery' === get_post_format() ) {
			$post = get_post();

			$blocks = parse_blocks( $post->post_content );

			foreach ( $blocks as $block ) {
				$images = array_merge( $images, csco_block_post_parse_gallery( $block ) );
			}

			$images = array_unique( $images );
		}

		if ( $images ) {
			?>
			<div class="cs-entry__gallery">
				<?php
				$counter = 0;
				foreach ( $images as $index => $image ) {
					$image_size    = 'csco-thumbnail';
					$overlay_class = 'cs-overlay-background';
					if ( 0 < $counter ) {
						$image_size = 'csco-smaller';
					}
					if ( 2 > $counter ) {
						$overlay_class .= ' cs-overlay-transparent';
					}
					?>
					<div class="cs-entry__thumbnail cs-entry__overlay" data-scheme="inverse">
						<div class="<?php echo esc_attr( $overlay_class ); ?>">
							<?php echo wp_get_attachment_image( $image, $image_size ); ?>

							<?php
							if ( 0 === $counter ) {
								if ( isset( $options['video'] ) && $options['video'] ) {
									csco_get_video_background( null, null, $options['video_template'], $options['video_controls'], $options['video_controls'] );
								}

								if ( count( $images ) < 2 && isset( $options['post_format'] ) && $options['post_format'] ) {
									csco_the_post_format_icon();
								}
							}
							?>

						</div>
						<?php if ( count( $images ) > 3 && $counter > 1 ) { ?>
							<div class="cs-overlay-content">
								<div class="cs-entry__gallery-count">
									<span class="cs-entry__gallery-plus">+</span>
									<span class="cs-entry__gallery-number"><?php echo esc_html( count( $images ) - 3 ); ?></span>
								</div>
							</div>
						<?php } ?>
						<a href="<?php the_permalink(); ?>" class="cs-overlay-link"></a>
					</div>
					<?php
					if ( 2 === $counter ) {
						break;
					}
					$counter++;
				}
				?>
			</div>
			<?php
		}
	}
}
